diff --git a/OpenSim/Region/Application/OpenSim.cs b/OpenSim/Region/Application/OpenSim.cs
index 27b669408a..66c7c48a20 100644
--- a/OpenSim/Region/Application/OpenSim.cs
+++ b/OpenSim/Region/Application/OpenSim.cs
@@ -323,6 +323,10 @@ namespace OpenSim
case "save-oar":
SaveOar(cmdparams);
break;
+
+ case "save-inv":
+ SaveInv(cmdparams);
+ break;
case "plugin":
m_sceneManager.SendCommandToPluginModules(cmdparams);
@@ -724,9 +728,13 @@ namespace OpenSim
}
}
+ ///
+ /// Load a whole region from an opensim archive.
+ ///
+ ///
protected void LoadOar(string[] cmdparams)
{
- m_log.Warn("[CONSOLE]: Experimental functionality. Please don't rely on this.");
+ m_log.Warn("[CONSOLE]: Experimental functionality. Please don't rely on this yet.");
m_log.Warn("[CONSOLE]: See http://opensimulator.org/wiki/OpenSim_Archives for more details.");
if (cmdparams.Length > 0)
@@ -739,9 +747,13 @@ namespace OpenSim
}
}
+ ///
+ /// Save a region to a file, including all the assets needed to restore it.
+ ///
+ ///
protected void SaveOar(string[] cmdparams)
{
- m_log.Warn("[CONSOLE]: Experimental functionality. Please don't rely on this.");
+ m_log.Warn("[CONSOLE]: Experimental functionality. Please don't rely on this yet.");
m_log.Warn("[CONSOLE]: See http://opensimulator.org/wiki/OpenSim_Archives for more details.");
if (cmdparams.Length > 0)
@@ -752,7 +764,16 @@ namespace OpenSim
{
m_sceneManager.SaveCurrentSceneToArchive(DEFAULT_OAR_BACKUP_FILENAME);
}
- }
+ }
+
+ ///
+ /// Save inventory to a file.
+ ///
+ ///
+ protected void SaveInv(string[] cmdparams)
+ {
+ m_log.Error("[CONSOLE]: This has not been implemented yet!");
+ }
private static string CombineParams(string[] commandParams, int pos)
{
diff --git a/OpenSim/Region/Environment/Scenes/Scene.Inventory.cs b/OpenSim/Region/Environment/Scenes/Scene.Inventory.cs
index d0c5842eaf..0ba5121d12 100644
--- a/OpenSim/Region/Environment/Scenes/Scene.Inventory.cs
+++ b/OpenSim/Region/Environment/Scenes/Scene.Inventory.cs
@@ -1784,6 +1784,7 @@ namespace OpenSim.Region.Environment.Scenes
}
}
}
+
public LLUUID attachObjectAssetStore(IClientAPI remoteClient, SceneObjectGroup grp, LLUUID AgentId)
{
SceneObjectGroup objectGroup = grp;
diff --git a/OpenSim/Region/Application/OpenSimBase.cs b/OpenSim/Region/Application/OpenSimBase.cs
index c2d30e4db7..a9351d31d4 100644
--- a/OpenSim/Region/Application/OpenSimBase.cs
+++ b/OpenSim/Region/Application/OpenSimBase.cs
@@ -62,14 +62,19 @@ namespace OpenSim
protected int proxyOffset = 0;
///
/// The file used to load and save prim backup xml if none has been specified
///
protected const string DEFAULT_PRIM_BACKUP_FILENAME = "prim-backup.xml";
///
/// The file use to load and save an opensim archive if none has been specified
///
protected const string DEFAULT_OAR_BACKUP_FILENAME = "scene_oar.tar.gz";
+
+ ///
+ /// The file to load and save inventory if no filename has been specified
+ ///
+ protected const string DEFAULT_INV_BACKUP_FILENAME = "opensim_inv.tar.gz";
public string m_physicsEngine;
public string m_meshEngineName;
@@ -62,14 +62,19 @@ namespace OpenSim
protected int proxyOffset = 0;
///
- /// The file used to load and save prim backup xml if none has been specified
+ /// The file used to load and save prim backup xml if no filename has been specified
///
protected const string DEFAULT_PRIM_BACKUP_FILENAME = "prim-backup.xml";
@@ -62,14 +62,19 @@ namespace OpenSim
protected const string DEFAULT_PRIM_BACKUP_FILENAME = "prim-backup.xml";
///
- /// The file use to load and save an opensim archive if none has been specified
+ /// The file used to load and save an opensim archive if no filename has been specified
///
protected const string DEFAULT_OAR_BACKUP_FILENAME = "scene_oar.tar.gz";